@@ -138,6 +138,14 @@ test_that("EQ-5D-5L Spain gives correct answer", {
   expect_equal(eq5d5l(c(MO=5,SC=5,UA=5,PD=5,AD=5), "Spain"), -0.416)
 })
 
+test_that("EQ-5D-5L Sweden gives correct answer", {
+  expect_equal(eq5d5l(c(MO=1,SC=1,UA=1,PD=1,AD=1), "Sweden"), 0.975, tolerance = .0011)
+  expect_equal(eq5d5l(c(MO=1,SC=2,UA=3,PD=4,AD=5), "Sweden"), 0.497)
+  expect_equal(eq5d5l(c(MO=2,SC=2,UA=3,PD=3,AD=5), "Sweden"), 0.528)
+  expect_equal(eq5d5l(c(MO=3,SC=4,UA=5,PD=4,AD=3), "Sweden"), 0.503)
+  expect_equal(eq5d5l(c(MO=5,SC=5,UA=5,PD=5,AD=5), "Sweden"), 0.243)
+})
+
 test_that("EQ-5D-5L Taiwan gives correct answer", {
   expect_equal(eq5d5l(c(MO=1,SC=1,UA=1,PD=1,AD=1), "Taiwan"), 1)
   expect_equal(eq5d5l(c(MO=1,SC=2,UA=3,PD=4,AD=5), "Taiwan"), 0.039, tolerance = .0011)
@@ -182,4 +190,5 @@ test_that("EQ-5D-5L throws error for incorrect parameters", {
   expect_error(eq5d5l(c(MD=5,SC=5,UA=5,PD=5,AD=5), "China"))
   expect_error(eq5d5l(c(MO=1,SC=7,UA=1,PD=1,AD=1), "Canada"))
   expect_error(eq5d5l(c(MO=1,SC=2,UA=3,PD=4,AD=5), "Swaziland"))
+  expect_error(eq5d5l(c(3, 4, 5, 4, 3), "Sweden"))
 })
